"use strict";

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.BadgeSize = exports.BadgeIntent = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _reactIntl = require("react-intl");
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _terraVisuallyHiddenText = _interopRequireDefault(require("terra-visually-hidden-text"));
var _BadgeModule = _interopRequireDefault(require("./Badge.module.scss"));
var _excluded = ["size", "intent", "intl", "isReversed", "text", "icon", "visuallyHiddenText"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
var cx = _bind.default.bind(_BadgeModule.default);
var BadgeIntent = exports.BadgeIntent = {
  DEFAULT: 'default',
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  INFO: 'info',
  WARNING: 'warning',
  POSITIVE: 'positive',
  NEGATIVE: 'negative'
};
var BadgeSize = exports.BadgeSize = {
  TINY: 'tiny',
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large',
  HUGE: 'huge'
};
var propTypes = {
  /**
   * Child Nodes.
   */
  children: _propTypes.default.node,
  /**
   * An optional icon. Nested inline with the text when provided.
   */
  icon: _propTypes.default.element,
  /**
   * Sets the badge color scheme. One of `default`, `primary`, `secondary`, `positive`, `negative`, `warning`, `info`.
   *
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue)
   * Follow the accessibility guidance for color to ensure color is not the only method used to convey information.
   */
  intent: _propTypes.default.oneOf(['default', 'primary', 'secondary', 'info', 'warning', 'positive', 'negative']),
  /**
   * @private
   * The intl object to be injected for translations.
   */
  intl: _propTypes.default.shape({
    formatMessage: _propTypes.default.func
  }),
  /**
   * Reverses the position of the icon and text.
   */
  isReversed: _propTypes.default.bool,
  /**
   * Sets the badge size. One of `tiny`, `small`, `medium`, `large`, `huge`.
   */
  size: _propTypes.default.oneOf(['tiny', 'small', 'medium', 'large', 'huge']),
  /**
   * Sets the badge text.
   *
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue)
   * It is best practice to always use text. Use text that conveys the meaning or purpose of the badge.
   */
  text: _propTypes.default.string,
  /**
   * Additional text that can be visually hidden but supports people that use assistive technologies like screen readers.
   *
   * ![IMPORTANT](https://badgen.net/badge/UX/Accessibility/blue)
   * Follow the Accessibility Guidance for visually hidden text above to better understand when to use this prop.
   */
  visuallyHiddenText: _propTypes.default.string
};
var defaultProps = {
  children: null,
  icon: null,
  intent: 'default',
  isReversed: false,
  size: 'small',
  text: null,
  visuallyHiddenText: undefined
};
var Badge = function Badge(_ref) {
  var size = _ref.size,
    intent = _ref.intent,
    intl = _ref.intl,
    isReversed = _ref.isReversed,
    text = _ref.text,
    icon = _ref.icon,
    visuallyHiddenText = _ref.visuallyHiddenText,
    customProps = _objectWithoutProperties(_ref, _excluded);
  var theme = _react.default.useContext(_terraThemeContext.default);
  var badgeClassNames = (0, _classnames.default)(cx('badge', {
    'has-icon': icon
  }, {
    'is-reversed': isReversed
  }, size, intent, theme.className), customProps.className);
  var badgeIcon = icon;
  if (icon && theme.className === 'redwood-theme') {
    badgeIcon = /*#__PURE__*/_react.default.cloneElement(icon, {
      className: (0, _classnames.default)(cx('badge-icon'))
    });
  }
  var textContent = text ? /*#__PURE__*/_react.default.createElement("span", {
    className: _BadgeModule.default.text
  }, text) : null;
  var visuallyHiddenTextContent = visuallyHiddenText ? /*#__PURE__*/_react.default.createElement(_terraVisuallyHiddenText.default, {
    text: visuallyHiddenText
  }) : null;
  var content = isReversed ? [textContent, visuallyHiddenTextContent, badgeIcon, customProps.children] : [badgeIcon, textContent, visuallyHiddenTextContent, customProps.children];
  return /*#__PURE__*/_react.default.createElement.apply(_react.default, ['span', _objectSpread(_objectSpread({}, customProps), {}, {
    className: badgeClassNames
  })].concat(content));
};
Badge.propTypes = propTypes;
Badge.defaultProps = defaultProps;
var _default = exports.default = (0, _reactIntl.injectIntl)(Badge);